@@ -71,6 +71,9 @@ def options_help() -> dict:
         f"Package groups to install.\n{pkg_group_choices}\nExample:"
         " [switch]-g[/] [meta]devops[/] [switch]-g[/switch] [meta]gaming",
 
+        'no_upgrade':
+        "Do not upgrade the existing brew or apt packages.",
+
         'remote_host':
         'Setup SSH on a random port & add [meta]IP_ADDR[/] to firewall',
 
@@ -160,4 +163,4 @@ class RichCommand(click.Command):
 
         # I use this to print a pretty svg at the end sometimes
         if RECORD:
-            console.save_svg("docs/onboardme/screenshots/help_text.svg")
+            console.save_svg("docs/onboardme/screenshots/help_text.svg", title="term")
