@@ -37,7 +37,9 @@ def rotate_github_ssh_keys() -> None:
             known_hosts.write(line)
 
 
-def run_preinstall_cmds(cmd_list: list, pkg_groups: list) -> None:
+def run_preinstall_cmds(cmd_list: list, 
+                        pkg_groups: list, 
+                        no_upgrade: bool) -> None:
     """
     takes a list of package manager pre-install commands and runs them
     if second list of package groups contains gaming, runs additional commands
@@ -47,7 +49,12 @@ def run_preinstall_cmds(cmd_list: list, pkg_groups: list) -> None:
     if 'gaming' in pkg_groups:
         run_gaming_setup = True
 
-    for pre_cmd in ['setup', 'update', 'upgrade']:
+    pre_cmds = ['setup', 'update', 'upgrade']
+
+    if no_upgrade:
+        pre_cmds.pop(2)
+
+    for pre_cmd in pre_cmds:
         if pre_cmd in cmd_list:
             if pre_cmd == 'update' and 'apt' in pre_cmd:
                 if run_gaming_setup:
@@ -64,7 +71,7 @@ def run_preinstall_cmds(cmd_list: list, pkg_groups: list) -> None:
             sub_header(f"[b]{pre_cmd.title()}[/b] completed.")
 
 
-def run_pkg_mngrs(pkg_mngrs: list, pkg_groups=[]) -> None:
+def run_pkg_mngrs(pkg_mngrs: list, pkg_groups=[], no_upgrade=bool) -> None:
     """
     Installs brew and pip3.11 packages. Also apt, snap, and flatpak on Linux.
     Takes optional variables:
@@ -102,6 +109,9 @@ def run_pkg_mngrs(pkg_mngrs: list, pkg_groups=[]) -> None:
             # commands for listing, installing, updating, upgrading, & cleanup
             pkg_cmds = pkg_mngr_dict['commands']
 
+            # make sure we use any required env vars during installs
+            install_env_vars = pkg_mngr_dict.get('env_vars', None)
+
             if pkg_mngr == 'snap' and not shutil.which('snap'):
                 log.warn("snap is either not installed, or you need to log out"
                          "and back in (or reboot) for it to be available. "
@@ -115,7 +125,7 @@ def run_pkg_mngrs(pkg_mngrs: list, pkg_groups=[]) -> None:
                     install_brew_taps(pkg_mngr_dict['taps']['macOS'])
 
             # run package manager specific setup if needed: update/upgrade
-            run_preinstall_cmds(pkg_cmds, pkg_groups)
+            run_preinstall_cmds(pkg_cmds, pkg_groups, no_upgrade)
 
             # run the list command for the given package manager
             list_cmd = pkg_cmds['list']
@@ -134,13 +144,16 @@ def run_pkg_mngrs(pkg_mngrs: list, pkg_groups=[]) -> None:
             for pkg_group in pkg_groups:
                 # if package group is in the packages.yaml file
                 if pkg_group in available_pkg_groups:
-                    if pkg_group == "macOS":
-                        # zathura needs some help on macOS
-                        check_zathura()
+                    # used to be for zathura, a document viewer, might delete
+                    # if pkg_group == "macOS":
+                    #     # zathura needs some help on macOS
+                    #     check_zathura()
 
                     install_pkg_group(pkg_cmds['install'],
                                       available_pkg_groups[pkg_group],
-                                      installed_pkgs)
+                                      installed_pkgs,
+                                      install_env_vars,
+                                      no_upgrade)
                     sub_header(f'{pkg_group.title()} packages installed.')
 
             # run final cleanup commands, if any
@@ -149,8 +162,12 @@ def run_pkg_mngrs(pkg_mngrs: list, pkg_groups=[]) -> None:
                 sub_header("[b]Cleanup[/b] step Completed.")
 
 
-def install_pkg_group(install_cmd: str, pkgs_to_install: list,
-                      installed_pkgs: list) -> None:
+def install_pkg_group(install_cmd: str, 
+                      pkgs_to_install: list,
+                      installed_pkgs: list, 
+                      install_env_vars: dict,
+                      no_upgrade: bool
+                      ) -> None:
     """
     Installs packages if they are not already installed.
     provided install command string.
@@ -176,7 +193,7 @@ def install_pkg_group(install_cmd: str, pkgs_to_install: list,
 
             log.debug(f"Checking if {pkg_short_name} is installed...")
             if pkg_short_name in installed_pkgs:
-                if 'upgrade' not in install_cmd:
+                if no_upgrade or 'upgrade' not in install_cmd:
                     log.info(f"{pkg} already installed. Moving on.")
                     # continues to the next pkg in the pkgs_to_install list
                     continue
@@ -185,7 +202,7 @@ def install_pkg_group(install_cmd: str, pkgs_to_install: list,
                     log.info(f"Upgrading {pkg} now...")
 
         # Actual installation
-        subproc([install_cmd + pkg], quiet=True)
+        subproc([install_cmd + pkg], quiet=True, env=install_env_vars)
 
 
 def install_brew_taps(taps: list) -> None:
@@ -194,7 +211,12 @@ def install_brew_taps(taps: list) -> None:
     in a list of git repos from packages.yaml, and aren't already tapped
     """
     log.info("Checking current taps.")
-    current_taps = subproc(["brew tap"]).split('\n')
+    existing_taps = subproc(["brew tap"])
+    try:
+        current_taps = existing_taps.split('\n')
+    except:
+        current_taps = []
+    
     log.debug(f"taps list is: {taps}")
     log.debug(f"Current taps are: {current_taps}")
 
@@ -208,15 +230,16 @@ def install_brew_taps(taps: list) -> None:
             log.info(f"{tap} already installed. Moving on.")
 
 
-def check_zathura() -> None:
-    """
-    make sure zathura is installed on macos
-    installs via brew if it's not installed
-    always returns True if everything was successful
-    """
-    if not shutil.which("zathura"):
-        zathura_pdf = "$(brew --prefix zathura-pdf-mupdf)"
-        cmds = ["mkdir -p $(brew --prefix zathura)/lib/zathura",
-                f"ln -s {zathura_pdf}/libpdf-mupdf.dylib" +
-                f"{zathura_pdf}/lib/zathura/libpdf-mupdf.dylib"]
-        subproc(cmds, quiet=True)
+# not currently using zathura on macOS, so removing as it's untested
+# def check_zathura() -> None:
+#     """
+#     make sure zathura is installed on macos
+#     installs via brew if it's not installed
+#     always returns True if everything was successful
+#     """
+#     if not shutil.which("zathura"):
+#         zathura_pdf = "$(brew --prefix zathura-pdf-mupdf)"
+#         cmds = ["mkdir -p $(brew --prefix zathura)/lib/zathura",
+#                 f"ln -s {zathura_pdf}/libpdf-mupdf.dylib" +
+#                 f"{zathura_pdf}/lib/zathura/libpdf-mupdf.dylib"]
+#         subproc(cmds, quiet=True)
